State class

State/region model for a country.

Constructors

State({required String name, required String stateCode})
Creates a State instance.
State.fromJson(Map<String, dynamic> json)
Creates a State from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
State or region name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateCode String
State code, when available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited