Country class
Country model used by CountryStatePicker.
Constructors
-
Country({required List<
State> states, required String name, required String iso2, required String iso3, required String phoneCode, required String currencyName, required String currencySymbol, required String tld, required String region, required String emoji, required String emojiU}) - Creates a Country instance.
-
Country.fromJson(Map<
String, dynamic> json) -
Creates a Country from JSON.
factory
Properties
- currencyName → String
-
Currency name, e.g. "Ghanaian cedi".
final
- currencySymbol → String
-
Currency symbol, e.g. "GH₵".
final
- emoji → String
-
Country flag emoji.
final
- emojiU → String
-
Unicode sequence for the flag emoji.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iso2 → String
-
ISO-3166 alpha-2 code, e.g. "GH".
final
- iso3 → String
-
ISO-3166 alpha-3 code, e.g. "GHA".
final
- name → String
-
Country display name, e.g. "Ghana".
final
- phoneCode → String
-
International phone code, e.g. "233".
final
- region → String
-
Region name, e.g. "Africa".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
states
→ List<
State> -
List of states/regions for this country.
final
- tld → String
-
Top-level domain, e.g. ".gh".
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited